@@ -13,9 +13,8 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
-from groundx.type.bucket_detail import BucketDetail
 from groundx.type.project_detail import ProjectDetail
 
 class RequiredProjectListResponse(TypedDict):
